########################################################################
###########   政府环境信息披露提升环境治理成效  ########################
###                 时培豪  吴传清 黄庆华
########################################################################
# 基础性设置
rm(list = ls(all=TRUE))              
gc()  

#
timestart<-Sys.time()                                          
memory.limit(102400)   

#
options(digits=4)                                                 
options(warn = -1)                                                
options(stringsAsFactors = F)                                     

windowsFonts(A=windowsFont("Times New Roman"),
             B=windowsFont("Arial"))      

########################################################################
# 加载包
library(ggplot2)
library(dplyr)
library(tidyr)
library(readr)
library(purrr)
library(tibble)
library(stringr)
library(forcats)
library(haven)
library(openxlsx)
library(foreign)
library(magrittr)
library(reshape)
library(lubridate)
library(ggridges)
library(ggsci)


########################################################################
# 主题

theme_set(theme_bw())           # 全局设置主题
theme_ETBM <- function(){
  theme_bw()+
    theme(plot.title = element_text(size = 10, hjust = 0.5),     
          plot.margin=  unit(c(0,0.2,0,0.2),'cm'), 
          plot.caption=element_text(colour = "black", hjust=0, family="Times", size=13,margin = margin(0, 0, 0, 0)),  
          panel.background=element_rect(fill='White'), 
          panel.border = element_blank(),     
          panel.grid = element_blank(),       
          panel.margin = unit(c(rep(1,4)),'mm'),  
          axis.line = element_line(color = "black", size=0.4, linetype="solid"),  
          axis.text.x=element_text(family="Times", size=10, vjust=-0.5,  
                                   margin= unit(c(0.2,0.2,0.2,0.2), "cm")),  
          axis.text.y=element_text(family="Times", size=10, hjust = 0.2,    
                                   margin= unit(c(0.2,0.2,0.2,0.2), "cm")), 
          axis.title.x = element_text(family="Times", size=10, hjust=1,      
                                      margin= unit(c(0.1,0.2,0.2,0.2), "mm")), 
          axis.title.y = element_text(family="Times", size=10, angle =90 ,vjust = 1, 
                                      margin= unit(c(0.1,0.2,0.2,0.2), "mm")),
          axis.ticks = element_line(color = "black", size=0.4, linetype="solid"), 
          axis.ticks.length = unit(-0.1, "cm"), 
          legend.background = element_rect(fill = "white"),  
          legend.position="right" )
}


########################################################################
#################        平行趋势检验图形        #######################
########################################################################
pre1 <- c(pre1, 0, 0, 0)
paralDisclose <- bind_rows(paralDisclose, pre1)

paralcheck <- paralDisclose %>% mutate(Did = fct_recode(Did,       
                                                     "-3" = "pre3",
                                                     "-2" = "pre2",  
                                                     "-1" = "pre1",
                                                     "0"  = "current",
                                                     "1"  = "after1",
                                                     "2"  = "after2",
                                                     "3"  = "after3",
                                                     "4"  = "after4",
                                                     "5"  = "after5"))

palist <-  c("-3", "-2", "-1", "0", "1", "2",  "3", "4", "5")
paralcheck <- paralcheck %>% mutate(Did = fct_relevel(Did, palist))
paralcheck %>% str()


parrel <-
  ggplot(data=paralcheck, aes(x=Did, y=Coef)) +
  geom_line(aes(group=""), color = "grey30", size=0.5, linetype="solid") + #折线图不出线
  geom_point(size = 2.4, shape = 17, color = "grey30") +
  geom_errorbar(aes(ymin = Low, ymax = High), width = 0.2, size = 0.4, color = "grey30") +
  geom_hline(yintercept = 0,  color = "red", linetype =  2,  size=0.5) +
  labs(title=NULL,     #  图形标题 "title"  
       subtitle=NULL,  #   
       caption = NULL,
       x =  "相对期数",
       y =  "估计系数") +
  theme_ETBM() 


########################################################################
##################        安慰剂检验图形        ########################
########################################################################

###### 图1
pig1 <-
  ggplot(did500, aes(x= t_value)) +
  geom_histogram(aes(y=..density..), colour="#636363", fill="#636363", alpha=.2)+
  geom_density(width = 0.4, size = 0.8, color = "red") +
  geom_vline(xintercept = -3.883,  color = "red", linetype =  2, size=0.7) +
  labs(title=NULL,     
       subtitle=NULL,  
       caption = NULL,
       x =  "t值",
       y =  "核密度") +
  theme_ETBM() +
  theme(axis.title = element_text(family = "A"),
        axis.text = element_text( family = "A"))


###### 图2
pig2 <-
  ggplot(did1000, aes(x= t_value)) +
  geom_histogram(aes(y=..density..), colour="#636363", fill="#636363", alpha=.2)+
  geom_density(width = 0.4, size = 0.8, color = "red") +
  geom_vline(xintercept = -3.883,  color = "red", linetype =  2, size=0.7) +
  labs(title=NULL,     
       subtitle=NULL,     
       caption = NULL,
       x =  "t值",
       y =  "核密度") +
  theme_ETBM() +
  theme(axis.title = element_text(family = "A"), 
        axis.text = element_text( family = "A"))


###### 图3 
pig3 <-
  ggplot(Disclose500, aes(x= t_value)) +
  geom_histogram(aes(y=..density..), colour="#636363", fill="#636363", alpha=.2)+
  geom_density(width = 0.4, size = 0.8, color = "red") +
  geom_vline(xintercept = -3.883,  color = "red", linetype =  2, size=0.7) +
  labs(title=NULL,      
       subtitle=NULL,     
       caption = NULL,
       x =  "t值",
       y =  "核密度") +
  theme_ETBM() +
  theme(axis.title = element_text(family = "A"), #坐标轴标签字体
        axis.text = element_text( family = "A"))



###### 图4
pig4 <-
  ggplot(Disclose1000, aes(x= t_value)) +
  geom_histogram(aes(y=..density..), colour="#636363", fill="#636363", alpha=.2)+
  geom_density(width = 0.4, size = 0.8, color = "red") +
  geom_vline(xintercept = -3.883,  color = "red", linetype =  2, size=0.7) +
  labs(title=NULL,      
       subtitle=NULL,   
       caption = NULL,
       x =  "t值",
       y =  "核密度")+
  theme_ETBM() +
  theme(axis.title = element_text(family = "A"),
        axis.text = element_text( family = "A"))

